// Messages are sent to the user in one of two ways:
//  - Mobile users are sent notifications
//  - Web users are sent emails
// Additionally to that, your messages are available within the app, kind of like an inbox
// This data model relates to the list of messages within the app, and it's separate from the notifications / emails
// When the notification is received, I will create a new Message and store it in my local database, but I will also need 
// to load in these objects from your API to make sure everything is in sync. 
// For example, some users will turn off Notifications, but they will still want to see messages in the app
Ext.regModel ("app.models.Message", {
	fields: [
		// this is just an internal reference I'm using, doesn't need to relate to your primary key or anything
		{name : 'id', 		type : 'int'},
		
		// the date of the message
		{name : 'date',		type : 'date'},
		
		// the text of the message
		{name : 'message',	type : 'string'},
		
		// I guess there will be various actions in the notifications… something of them will take you to a piece of content,
		// others will prompt you to visit the GP, others will be more general. 
		// I suppose this field will have one of a number of different strings, could be 'content', 'visitGP' etc etc
		{name : 'action',	type : 'string'},
		
		// where required, this field will contain the additional detail for the message
		// for example, if action is 'content', the detail field will contain a reference to the content ID we are linking to
		// I've put it as a string here so it can handle lots of different types of data
		{name : 'detail',	type : 'string'}
	]
});